@@ -11,14 +11,13 @@
 
 #include <QObject>
 
-#include "types.h"
 #include "bluezqt_export.h"
+#include "types.h"
 
 class QDBusObjectPath;
 
 namespace BluezQt
 {
-
 class PendingCall;
 
 /**
@@ -42,7 +41,7 @@ public:
     /**
      * Destroys an ObexSession object.
      */
-    ~ObexSession();
+    ~ObexSession() override;
 
     /**
      * Returns a shared pointer from this.
